==============
Code reference
==============

.. toctree::
  :maxdepth: 2


core
----
.. automodule:: ggf.core
   :members:
   :undoc-members:


globgeomfact
------------
.. automodule:: ggf.globgeomfact
   :members:
   :undoc-members:


matlab_funcs
------------
.. automodule:: ggf.matlab_funcs
   :members:
   :undoc-members:


sci_funcs
------------
.. automodule:: ggf.sci_funcs
   :members:
   :undoc-members:


stretcher
---------
.. automodule:: ggf.stretcher
   :members:
   :undoc-members:
